@@ -1,21 +1,24 @@
 /*
- * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- */
+
+   xlog - GTK+ logging program for amateur radio operators
+   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+
+   This file is part of xlog.
+
+   Xlog is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Xlog is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with xlog.  If not, see <http://www.gnu.org/licenses/>.
+
+*/
 
 /*
  * callbacks_mainwindow_qsoframe.c - callbacks for the QSO frame, where all
@@ -59,7 +62,7 @@ void *shareCall;
 
 extern GtkWidget *mainwindow, *b4window, *keyerwindow;
 extern gint callid;
-extern statetype state;
+extern programstatetype programstate;
 extern GList *logwindowlist;
 extern preferencestype preferences;
 extern GList *logwindowlist;
@@ -278,6 +281,7 @@ void
 on_callentry_changed (GtkEditable * editable, gpointer user_data)
 {
 	gchar *call;
+	guint st, zone, cont;
 #if HAVE_SYS_SHM_H
 	gchar *errorstr;
 #endif
@@ -286,9 +290,9 @@ on_callentry_changed (GtkEditable * editable, gpointer user_data)
 
 	GtkWidget *awardsentry = lookup_widget (mainwindow, "awardsentry");
 	gchar *aw = gtk_editable_get_chars (GTK_EDITABLE (awardsentry), 0, -1);
-	gchar *result = valid_awards_entry (aw);
+	gchar *result = valid_awards_entry (aw, &st, &zone, &cont);
 	if (!result)
-		updatedxccframe (call, FALSE);
+		updatedxccframe (call, FALSE, st, zone, cont);
 	else
 		g_free (result);
 	g_free (aw);
@@ -296,25 +300,25 @@ on_callentry_changed (GtkEditable * editable, gpointer user_data)
 
 	/* twpsk support, if no IPC ID yet, create one */
 #if HAVE_SYS_SHM_H
-	if (state.shmid == -1)
+	if (programstate.shmid == -1)
 	{
-		if ((state.shmid = shmget (KEY, SHMSIZE, IPC_CREAT | 0600)) < 0)
+		if ((programstate.shmid = shmget (KEY, SHMSIZE, IPC_CREAT | 0600)) < 0)
 		{
 			errorstr = g_strdup_printf
 				(_("shmget failed: %s"), g_strerror (errno));
 			update_statusbar (errorstr);
 			g_free (errorstr);
 		}
-		if ((shareCall = (shmat (state.shmid, NULL, 0))) == (gchar *) - 1)
+		if ((shareCall = (shmat (programstate.shmid, NULL, 0))) == (gchar *) - 1)
 		{
 			errorstr = g_strdup_printf
 				(_("shmat failed: %s"), g_strerror (errno));
 			update_statusbar (errorstr);
 			g_free (errorstr);
-			state.shmid = -1;
+			programstate.shmid = -1;
 		}
 	}
-	if (state.shmid != -1)
+	if (programstate.shmid != -1)
 		strncpy (shareCall, call, SHMSIZE);	/* put call in shm */
 #endif
 
@@ -324,18 +328,20 @@ on_callentry_changed (GtkEditable * editable, gpointer user_data)
 void
 on_awardsentry_changed (GtkEditable * editable, gpointer user_data)
 {
+	guint st, zone, cont;
+
 	gchar *aw = gtk_editable_get_chars (editable, 0, -1);
-	gchar *result = valid_awards_entry (aw);
+	gchar *result = valid_awards_entry (aw,  &st, &zone, &cont);
 	if (result)
 	{
-		updatedxccframe (result, TRUE);
+		updatedxccframe (result, TRUE, st, zone, cont);
 		g_free (result);
 	}
 	else
 	{
 		GtkWidget *callentry = lookup_widget (mainwindow, "callentry");
 		gchar *call = gtk_editable_get_chars (GTK_EDITABLE (callentry), 0, -1);
-		updatedxccframe (call, FALSE);
+		updatedxccframe (call, FALSE, st, zone, cont);
 		g_free (call);
 	}
 	g_free (aw);
@@ -365,7 +371,7 @@ on_mhzbutton_clicked (GtkButton * button, gpointer user_data)
 	}
 	else /* there is no default */
 	{
-		if (state.rigfrequency != 0)
+		if (programstate.rigfrequency != 0)
 			digits = convert_frequency ();
 		else
 			g_string_printf (digits, "UNKNOWN");
@@ -400,7 +406,7 @@ on_modebutton_clicked (GtkButton * button, gpointer user_data)
 	}
 	else	/* NO default */
 	{
-		mode = rigmode (state.rigmode);
+		mode = rigmode (programstate.rigmode);
 		gtk_entry_set_text (GTK_ENTRY (entry), mode);
 		modeenum = mode2enum (mode);
 		if (modeenum >= 0)
@@ -440,8 +446,8 @@ on_rstbutton_clicked (GtkButton * button, gpointer user_data)
 		else
 			gtk_entry_set_text (GTK_ENTRY (rstentry), preferences.defaulttxrst);
 	}
-	else if (state.rigrst != 0)
-		gtk_entry_set_text (GTK_ENTRY (rstentry), state.rigrst);
+	else if (programstate.rigrst != 0)
+		gtk_entry_set_text (GTK_ENTRY (rstentry), programstate.rigrst);
 	else
 		gtk_entry_set_text (GTK_ENTRY (rstentry), "UNKNOWN");
 }
@@ -455,9 +461,9 @@ on_powerbutton_clicked (GtkButton * button, gpointer user_data)
 	entry = lookup_widget (mainwindow, "powerentry");
 	if (g_ascii_strcasecmp (preferences.defaultpower, "?"))
 		gtk_entry_set_text (GTK_ENTRY (entry), preferences.defaultpower);
-	else if (state.rigpower != 0)
+	else if (programstate.rigpower != 0)
 		{
-			rigpower = g_strdup_printf ("%d", state.rigpower * 256 / 100000);
+			rigpower = g_strdup_printf ("%d", programstate.rigpower / 1000);
 			gtk_entry_set_text (GTK_ENTRY (entry), rigpower);
 			g_free (rigpower);
 		}
