@@ -1,21 +1,24 @@
 /*
- * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- */
+
+   xlog - GTK+ logging program for amateur radio operators
+   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+
+   This file is part of xlog.
+
+   Xlog is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Xlog is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with xlog.  If not, see <http://www.gnu.org/licenses/>.
+
+*/
 
 /*
  * callbacks_mainwindow_toolbar.c - clickable toolbar
@@ -32,6 +35,7 @@
 #include "preferences.h"
 #include "log.h"
 #include "xlog_enum.h"
+#include "awards_enum.h"
 #include "utils.h"
 #include "main.h"
 #include "dxcc.h"
@@ -41,13 +45,14 @@
 extern GtkWidget *mainwindow, *scorewindow, *keyerwindow;
 extern GtkWidget *mainnotebook;
 extern preferencestype preferences;
-extern statetype state;
 extern gchar **bandsplit;
 extern gchar **modesplit;
 extern gchar **qso;
 extern GList *logwindowlist;
-extern gushort w[400][MAX_BANDS + 1];
-extern gushort c[400][MAX_BANDS + 1];
+extern gushort dxcc_w[400][MAX_BANDS + 1];
+extern gushort dxcc_c[400][MAX_BANDS + 1];
+extern gushort wac_w[MAX_CONTINENTS][MAX_BANDS + 1];
+extern gushort wac_c[MAX_CONTINENTS][MAX_BANDS + 1];
 
 /* add a new qso to the log */
 void
@@ -65,6 +70,7 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 	GtkTextIter start, end;
 	gchar *temp, *label;
 	gint bandindex, modeindex, i = 0, page, f, kms, l, result;
+	guint st, zone, cont;
 	logtype *logw = NULL;
 	GtkTreeIter iter, selected;
 	GtkTreeModel *model;
@@ -213,16 +219,19 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 			if (strlen(qso[LOCATOR]) >= 2)
 			{
 				result = wwl (preferences.locator, qso[LOCATOR], &kms, &l);
-				if (GTK_WIDGET_VISIBLE (unknown1hbox))
+				if (result == 0)
 				{
-					if (preferences.units == 1)
-						qso[U1] = g_strdup_printf ("%d km", kms);
-					else
-						qso[U1] = g_strdup_printf ("%d m", (gint) (kms/1.609));
-				}
-				if (GTK_WIDGET_VISIBLE (unknown2hbox))
-				{
-					qso[U2] = g_strdup_printf ("%d deg", l);
+					if (GTK_WIDGET_VISIBLE (unknown1hbox))
+					{
+						if (preferences.units == 1)
+							qso[U1] = g_strdup_printf ("%d km", kms);
+						else
+							qso[U1] = g_strdup_printf ("%d m", (gint) (kms/1.609));
+					}
+					if (GTK_WIDGET_VISIBLE (unknown2hbox))
+					{
+						qso[U2] = g_strdup_printf ("%d deg", l);
+					}
 				}
 			}
 
@@ -259,7 +268,7 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 		if (GTK_WIDGET_VISIBLE(scorewindow))
 		{
 			/* update worked/confirmed array */
-			gchar *result = valid_awards_entry (qso[AWARDS]);
+			gchar *result = valid_awards_entry (qso[AWARDS], &st, &zone,  &cont);
 			if (result)
 			{
 				lookup = lookupcountry_by_prefix (result);
@@ -268,20 +277,33 @@ on_abutton_clicked (GtkButton * button, gpointer user_data)
 			else
 				lookup = lookupcountry_by_callsign (qso[CALL]);
 			f = freq2enum (qso[BAND]);
+			gboolean qslconfirmed = qslreceived (qso[QSLIN]);
 			if (preferences.scoringbands[f] == '1')
 			{
-				w[lookup.country][f]++;
-				w[lookup.country][MAX_BANDS]++;
-				if (!g_ascii_strcasecmp (qso[QSLIN], "x") ||
-					!g_ascii_strcasecmp (qso[QSLIN], "y"))
+				dxcc_w[lookup.country][f]++;
+				dxcc_w[lookup.country][MAX_BANDS]++;
+				if (qslconfirmed)
 				{
-					c[lookup.country][f]++;
-					c[lookup.country][MAX_BANDS]++;
+					dxcc_c[lookup.country][f]++;
+					dxcc_c[lookup.country][MAX_BANDS]++;
+				}
+				if (dxcc_w[lookup.country][f] == 1 || dxcc_c[lookup.country][f] == 1)
+					update_dxccscoring ();
+				if (cont != 99 || lookup.continent != 99)
+				{
+					if (cont == 99) cont = lookup.continent;
+					wac_w[cont][f]++;
+					wac_w[cont][MAX_BANDS]++;
+					if (qslconfirmed)
+					{
+						wac_c[cont][f]++;
+						wac_c[cont][MAX_BANDS]++;
+					}
+					if ((preferences.awardswac == 1) &&
+						(wac_w[cont][f] == 1 || wac_c[cont][f] == 1))
+						update_wacscoring ();
 				}
 			/* check if this is a new country and update scoring */
-				if (w[lookup.country][f] == 1 ||
-					c[lookup.country][f] == 1)
-					update_dxccscoring ();
 			}
 		}
 
@@ -331,6 +353,7 @@ on_dbutton_clicked (GtkButton * button, gpointer user_data)
 	gchar *qsonumber, *label, *call, *freq, *awards, *temp;
 	gboolean qslin;
 	gint i, page, f;
+	guint st, zone, cont;
 	logtype *logw;
 	GtkTreeIter selected, iter;
 	GtkTreeModel *model;
@@ -428,7 +451,7 @@ on_dbutton_clicked (GtkButton * button, gpointer user_data)
 			if (GTK_WIDGET_VISIBLE(scorewindow))
 			{
 				/* update worked/confirmed array */
-				gchar *result = valid_awards_entry (awards);
+				gchar *result = valid_awards_entry (awards,  &st, &zone,  &cont);
 				if (result)
 				{
 					lookup = lookupcountry_by_prefix (result);
@@ -440,17 +463,31 @@ on_dbutton_clicked (GtkButton * button, gpointer user_data)
 				f = freq2enum (freq);
 				if (preferences.scoringbands[f] == '1')
 				{
-					w[lookup.country][f]--;
-					w[lookup.country][MAX_BANDS]--;
+					dxcc_w[lookup.country][f]--;
+					dxcc_w[lookup.country][MAX_BANDS]--;
 					if (qslin)
 					{
-						c[lookup.country][f]--;
-						c[lookup.country][MAX_BANDS]--;
+						dxcc_c[lookup.country][f]--;
+						dxcc_c[lookup.country][MAX_BANDS]--;
 					}
 		/* check if this is the only country on this frequency */
-					if (w[lookup.country][f] == 0 ||
-						c[lookup.country][f] == 0)
+					if (dxcc_w[lookup.country][f] == 0 ||
+						dxcc_c[lookup.country][f] == 0)
 						update_dxccscoring ();
+					if (cont != 99 || lookup.continent != 99)
+					{
+						if (cont == 99) cont = lookup.continent;
+						wac_w[cont][f]--;
+						wac_w[cont][MAX_BANDS]--;
+						if (qslin)
+						{
+							wac_c[cont][f]--;
+							wac_c[cont][MAX_BANDS]--;
+						}
+						if ((preferences.awardswac == 1) &&
+							(wac_w[cont][f] == 0 || wac_c[cont][f] == 0))
+							update_wacscoring ();
+					}
 				}
 			}
 			if (preferences.saving == 2)
@@ -481,12 +518,14 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 		*framelabel;
 	GtkTextBuffer *b;
 	GtkTextIter start, end;
-	gint bandindex, modeindex, i = 0, page, f, result, kms, l;
-	gchar *temp, *label, *logcall, *logfreq, *logqslin, *logawards;
+	gint bandindex, modeindex, i = 0, page, fr, froption, result, kms, l;
+	guint st, zone, cont;
+	gchar *temp, *label, *logcall, *logfreq, *logqslin, *logawards, *logtime, *logendtime;
 	logtype *logw;
 	GtkTreeIter selected;
 	GtkTreeModel *model;
 	struct info lookup;
+	gboolean qslconfirmed;
 
 	page = gtk_notebook_get_current_page (GTK_NOTEBOOK (mainnotebook));
 
@@ -517,17 +556,29 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 			gtk_tree_model_get (model, &selected, NR, &qso[NR], -1);
 
 			qso[DATE] = gtk_editable_get_chars (GTK_EDITABLE (dateentry), 0, -1);
+
+			/* do not touch time if hours and seconds are equal */
+			gtk_tree_model_get (model, &selected, GMT, &logtime, -1);
 			qso[GMT] = gtk_editable_get_chars (GTK_EDITABLE (gmtentry), 0, -1);
+			if (!g_ascii_strncasecmp (logtime, qso[GMT], 4))
+				qso[GMT] = g_strdup (logtime);
+
+			gtk_tree_model_get (model, &selected, CALL, &logcall, -1);
 			qso[CALL] = gtk_editable_get_chars (GTK_EDITABLE (callentry), 0, -1);
 
+			gtk_tree_model_get (model, &selected, BAND, &logfreq, -1);
 			if (preferences.bandseditbox == 1)
 			{
 				qso[BAND] = gtk_editable_get_chars (GTK_EDITABLE (bandentry), 0, -1);
 			}
 			else
 			{
+				fr = freq2enum (logfreq);
 				bandindex = gtk_combo_box_get_active (GTK_COMBO_BOX(bandoptionmenu));
 				qso[BAND] = lookup_band (bandindex);
+				/* do not touch freq in the log if it's the same as optionmenu */
+				froption = freq2enum (qso[BAND]);
+				if (fr == froption) qso[BAND] = g_strdup (logfreq);
 			}
 
 			if (preferences.modeseditbox == 1)
@@ -543,10 +594,13 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 			awardshbox = lookup_widget (mainwindow, "awardshbox");
 			if (GTK_WIDGET_VISIBLE (awardshbox))
 			{
+				gtk_tree_model_get (model, &selected, AWARDS, &logawards, -1);
 				awardsentry = lookup_widget (mainwindow, "awardsentry");
 				qso[AWARDS] = gtk_editable_get_chars (GTK_EDITABLE (awardsentry), 0, -1);
 				gtk_editable_delete_text (GTK_EDITABLE (awardsentry), 0, -1);
 			}
+			else
+				logawards = g_strdup ("");
 
 			powerhbox = lookup_widget (mainwindow, "powerhbox");
 			if (GTK_WIDGET_VISIBLE (powerhbox))
@@ -562,14 +616,18 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 			endhbox = lookup_widget (mainwindow, "endhbox");
 			if (GTK_WIDGET_VISIBLE (endhbox))
 			{
+				gtk_tree_model_get (model, &selected, GMTEND, &logendtime, -1);
 				endentry = lookup_widget (mainwindow, "endentry");
 				qso[GMTEND] = gtk_editable_get_chars (GTK_EDITABLE (endentry), 0, -1);
+				if (!g_ascii_strncasecmp (logendtime, qso[GMTEND], 4))
+					qso[GMTEND] = g_strdup (logendtime);
 				gtk_editable_delete_text (GTK_EDITABLE (endentry), 0, -1);
 			}
 
 			qslhbox = lookup_widget (mainwindow, "qslhbox");
 			if (GTK_WIDGET_VISIBLE (qslhbox))
 			{
+				gtk_tree_model_get (model, &selected, QSLIN, &logqslin, -1);
 				incheckbutton = lookup_widget (mainwindow, "incheckbutton");
 				outcheckbutton = lookup_widget (mainwindow, "outcheckbutton");
 				if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON (outcheckbutton)))
@@ -583,6 +641,8 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 				gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON	(outcheckbutton), FALSE);
 				gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (incheckbutton), FALSE);
 			}
+			else
+				logqslin = g_strdup ("");
 
 			namehbox = lookup_widget (mainwindow, "namehbox");
 			if (GTK_WIDGET_VISIBLE (namehbox))
@@ -635,28 +695,25 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 				gtk_text_buffer_set_text (b, "", 0);
 			}
 
-			/* save call and freq for scoring */
-			gtk_tree_model_get (model, &selected, CALL, &logcall, -1);
-			gtk_tree_model_get (model, &selected, BAND, &logfreq, -1);
-			gtk_tree_model_get (model, &selected, QSLIN, &logqslin, -1);
-			gtk_tree_model_get (model, &selected, AWARDS, &logawards, -1);
-
 			/* calculate distance and azimuth */
 			if ((preferences.distqrb == 1) && GTK_WIDGET_VISIBLE (locatorhbox))
 			{
 				if (strlen(qso[LOCATOR]) >= 2)
 				{
-				result = wwl (preferences.locator, qso[LOCATOR], &kms, &l);
-					if (GTK_WIDGET_VISIBLE (unknown1hbox))
+					result = wwl (preferences.locator, qso[LOCATOR], &kms, &l);
+					if (result == 0)
 					{
-						if (preferences.units == 1)
-							qso[U1] = g_strdup_printf ("%d km", kms);
-						else
-							qso[U1] = g_strdup_printf ("%d m", (gint) (kms/1.609));
-					}
-					if (GTK_WIDGET_VISIBLE (unknown2hbox))
-					{
-						qso[U2] = g_strdup_printf ("%d deg", l);
+						if (GTK_WIDGET_VISIBLE (unknown1hbox))
+						{
+							if (preferences.units == 1)
+								qso[U1] = g_strdup_printf ("%d km", kms);
+							else
+								qso[U1] = g_strdup_printf ("%d m", (gint) (kms/1.609));
+						}
+						if (GTK_WIDGET_VISIBLE (unknown2hbox))
+						{
+							qso[U2] = g_strdup_printf ("%d deg", l);
+						}
 					}
 				}
 
@@ -689,7 +746,7 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 
 			if (GTK_WIDGET_VISIBLE(scorewindow))
 			{ /* first we delete, then we add */
-				gchar *result = valid_awards_entry (logawards);
+				gchar *result = valid_awards_entry (logawards, &st, &zone, &cont);
 				if (result)
 				{
 					lookup = lookupcountry_by_prefix (result);
@@ -698,22 +755,32 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 				else
 				lookup = lookupcountry_by_callsign (logcall);
 
-				f = freq2enum (logfreq);
-				if (preferences.scoringbands[f] == '1')
+				fr = freq2enum (logfreq);
+				qslconfirmed = qslreceived (logqslin);
+				if (preferences.scoringbands[fr] == '1')
 				{
 
-					w[lookup.country][f]--;
-					w[lookup.country][MAX_BANDS]--;
-
-					if (!g_ascii_strcasecmp (logqslin, "x") ||
-						!g_ascii_strcasecmp (logqslin, "y"))
+					dxcc_w[lookup.country][fr]--;
+					dxcc_w[lookup.country][MAX_BANDS]--;
+					if (qslconfirmed)
 					{
-						c[lookup.country][f]--;
-						c[lookup.country][MAX_BANDS]--;
+						dxcc_c[lookup.country][fr]--;
+						dxcc_c[lookup.country][MAX_BANDS]--;
+					}
+					if (cont != 99 || lookup.continent != 99)
+					{
+						if (cont == 99) cont = lookup.continent;
+						wac_w[cont][fr]--;
+						wac_w[cont][MAX_BANDS]--;
+						if (qslconfirmed)
+						{
+							wac_c[cont][fr]--;
+							wac_c[cont][MAX_BANDS]--;
+						}
 					}
 				}
 
-				result = valid_awards_entry (qso[AWARDS]);
+				result = valid_awards_entry (qso[AWARDS], &st, &zone, &cont);
 				if (result)
 				{
 					lookup = lookupcountry_by_prefix (result);
@@ -722,26 +789,41 @@ on_ubutton_clicked (GtkButton * button, gpointer user_data)
 				else
 				lookup = lookupcountry_by_callsign (qso[CALL]);
 
-				f = freq2enum (qso[BAND]);
-				if (preferences.scoringbands[f] == '1')
+				fr = freq2enum (qso[BAND]);
+				qslconfirmed = qslreceived (qso[QSLIN]);
+				if (preferences.scoringbands[fr] == '1')
 				{
 
-					w[lookup.country][f]++;
-					w[lookup.country][MAX_BANDS]++;
-
-					if (!g_ascii_strcasecmp (qso[QSLIN], "x") ||
-						!g_ascii_strcasecmp (qso[QSLIN], "y"))
+					dxcc_w[lookup.country][fr]++;
+					dxcc_w[lookup.country][MAX_BANDS]++;
+					if (qslconfirmed)
 					{
-						c[lookup.country][f]++;
-						c[lookup.country][MAX_BANDS]++;
+						dxcc_c[lookup.country][fr]++;
+						dxcc_c[lookup.country][MAX_BANDS]++;
+					}
+					if (cont != 99 || lookup.continent != 99)
+					{
+						if (cont == 99) cont = lookup.continent;
+						wac_w[cont][fr]++;
+						wac_w[cont][MAX_BANDS]++;
+						if (qslconfirmed)
+						{
+							wac_c[cont][fr]++;
+							wac_c[cont][MAX_BANDS]++;
+						}
 					}
 				}
-
 				/* don't bother if this is a new one or if a
 					country is deleted, just update scoring */
 				update_dxccscoring ();
+				if (preferences.awardswac == 1) update_wacscoring ();
 			}
 
+			g_free (logcall);
+			g_free (logfreq);
+			g_free (logqslin);
+			g_free (logawards);
+
 			if (preferences.saving == 2)
 			{
 				savelog (logw, logw->filename, TYPE_FLOG, 1, logw->qsos);
