@@ -1,21 +1,24 @@
 /*
- * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- */
+
+   xlog - GTK+ logging program for amateur radio operators
+   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+
+   This file is part of xlog.
+
+   Xlog is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Xlog is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with xlog.  If not, see <http://www.gnu.org/licenses/>.
+
+*/
 
 /* gui_aboutdialog.c - creation of the about dialog */
 
@@ -32,7 +35,7 @@ extern GtkWidget *mainwindow;
 static void
 handle_url (GtkAboutDialog *about, const char *link, gpointer data)
 {
-	gchar *command[] = {"firefox", NULL, NULL};
+	gchar *command[] = {"xdg-open", NULL, NULL};
 
 	command[1] = g_strdup (link);
 	g_spawn_async
@@ -43,7 +46,7 @@ handle_url (GtkAboutDialog *about, const char *link, gpointer data)
 static void
 handle_email (GtkAboutDialog *about, const char *link, gpointer data)
 {
-	gchar *command[] = {"evolution", NULL, NULL};
+	gchar *command[] = {"xdg-email", NULL, NULL};
 
 	command[1] = g_strdup_printf ("mailto:%s", link);
 	g_spawn_async
@@ -54,32 +57,31 @@ handle_email (GtkAboutDialog *about, const char *link, gpointer data)
 void
 on_menu_about_activate (GtkMenuItem * menuitem, gpointer user_data)
 {
-	gchar *authors[] = { "Joop Stakenborg PG4I <pg4i@amsat.org>", 
+	gchar *authors[] = { "Joop Stakenborg PG4I <pg4i@amsat.org>",
 		"Stephane Fillod F8CFE <f8cfe@free.fr>", NULL };
 	GdkPixbuf *pixbuf = create_pixbuf ("xlog.png");
 
 	gtk_about_dialog_set_url_hook (handle_url, NULL, NULL);
 	gtk_about_dialog_set_email_hook (handle_email, NULL, NULL);
 
-	gtk_show_about_dialog (GTK_WINDOW(mainwindow), 
+	gtk_show_about_dialog (GTK_WINDOW(mainwindow),
 		"authors", authors,
 		"comments", _("logbook program for amateur radio operators"),
-		"license", 
+		"license",
 "Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>\n"
 "\n"
-"This program is free software; you can redistribute it and/or modify\n"
+"Xlog is free software: you can redistribute it and/or modify\n"
 "it under the terms of the GNU General Public License as published by\n"
-"the Free Software Foundation; either version 2 of the License, or\n"
+"the Free Software Foundation, either version 3 of the License, or\n"
 "(at your option) any later version.\n"
 "\n"
-"This program is distributed in the hope that it will be useful,\n"
+"Xlog is distributed in the hope that it will be useful,\n"
 "but WITHOUT ANY WARRANTY; without even the implied warranty of\n"
-"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the\n"
-"GNU Library General Public License for more details.\n"
+"MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the\n"
+"GNU General Public License for more details.\n"
 "\n"
 "You should have received a copy of the GNU General Public License\n"
-"along with this program; if not, write to the Free Software\n"
-"Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.\n",
+"along with xlog.  If not, see <http://www.gnu.org/licenses/>.\n"
 		"website", "http://pg4i.chronos.org.uk/linux/xlog.html",
 		"logo", pixbuf,
 		"translator-credits",
@@ -87,6 +89,7 @@ on_menu_about_activate (GtkMenuItem * menuitem, gpointer user_data)
 "Danish: Alexandru Csete OZ9AEC <alexc@phys.au.dk>\n"
 "Dutch: Joop Stakenborg PG4I <pg4i@amsat.org>\n"
 "French: Jean-Luc Coulon F5IBH <jean-luc.coulon@wanadoo.fr>\n"
+"German: Martin Hautsch DL5MRH <<moadin@hautsch.net>\n"
 "Polish: Boguslaw Ciastek SQ5TB <ciacho@z.pl>\n"
 "Spanish: Jaime Robles EA4TV <jaime@robles.nu>\n"
 "Slovak: Michal Karas OM4AA <zoliq@ilm.utc.sk>\n"
