@@ -1,21 +1,24 @@
 /*
- * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- */
+
+   xlog - GTK+ logging program for amateur radio operators
+   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+
+   This file is part of xlog.
+
+   Xlog is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Xlog is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with xlog.  If not, see <http://www.gnu.org/licenses/>.
+
+*/
 
 /* gui_awards_dxcc.c */
 
@@ -28,11 +31,11 @@
 #include "preferences.h"
 
 extern GtkWidget *mainwindow;
-extern statetype state;
+extern programstatetype programstate;
 extern preferencestype preferences;
 extern GPtrArray *dxcc;
-extern gushort w[400][MAX_BANDS + 1];
-extern gushort c[400][MAX_BANDS + 1];
+extern gushort dxcc_w[400][MAX_BANDS + 1];
+extern gushort dxcc_c[400][MAX_BANDS + 1];
 
 void on_awards_dxcc_activate (GtkMenuItem *menuitem, gpointer user_data)
 {
@@ -215,23 +218,23 @@ void on_awards_dxcc_activate (GtkMenuItem *menuitem, gpointer user_data)
 
 	GtkTreeIter iter;
 	gint i, j;
-	for (i = 1; i < state.countries; i++)
+	for (i = 1; i < programstate.countries; i++)
 	{
 		dxcc_data *d = g_ptr_array_index (dxcc, i);
 		gtk_list_store_append (GTK_LIST_STORE (model), &iter);
 		gtk_list_store_set (GTK_LIST_STORE (model), &iter, 0, d->px, -1);
 		for (j = 0; j < MAX_BANDS; j++)
 		{
-			if (w[i][j] > 0)
+			if (dxcc_w[i][j] > 0)
 			{
-				gchar *str = g_strdup_printf ("%d", w[i][j]);
+				gchar *str = g_strdup_printf ("%d", dxcc_w[i][j]);
 				gtk_list_store_set (GTK_LIST_STORE (model), &iter, j+1, str, -1);
 				g_free (str);
 			}
 		}
 		for (j = 0; j < MAX_BANDS; j++)
 		{
-			if (c[i][j] > 0)
+			if (dxcc_c[i][j] > 0)
 			{
 				gtk_list_store_set (GTK_LIST_STORE (model), &iter, j+1, "0", -1);
 			}
