@@ -1,21 +1,24 @@
 /*
- * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- */
+
+   xlog - GTK+ logging program for amateur radio operators
+   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+
+   This file is part of xlog.
+
+   Xlog is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Xlog is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with xlog.  If not, see <http://www.gnu.org/licenses/>.
+
+*/
 
 /*
  * gui_dialogsdialog.c - creation and destruction of the dialogs dialog
@@ -29,9 +32,11 @@
 #include <gtk/gtk.h>
 
 #include "gui_dialogsdialog.h"
+#include "gui_scorewindow.h"
 #include "support.h"
 #include "preferences.h"
 #include "xlog_enum.h"
+#include "dxcc.h"
 
 extern GtkWidget *mainwindow;
 extern GtkWidget *b4window;
@@ -53,12 +58,13 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 		*bb1, *bb2, *bb3, *bb4, *bb5, *bb6, *bb7, *bb8, *bb9, *bb10,
 		*bb11, *bb12, *bb13, *bb14, *bb15, *bb16, *bb17, *bb18, *bb19,
 		*bb20, *bb21, *bb22, *bb23, *bb24, *bb25, *bb26, *bb27, *bb28,
-		*bb29,
+		*bb29, *vbox3, *bwac,
 		*countrytreeview, *dxcctreeview;
 	gchar **states, **split, *scoringbands;
 	gboolean check;
 	GtkTreeViewColumn *column;
-	gint i, response;
+	GtkTreeIter iter;
+	gint i, j, response;
 
 	split = g_strsplit(preferences.b4columns2, ",", 0);
 	dialogsdialog = gtk_dialog_new_with_buttons (_("xlog - dialogs and windows"),
@@ -395,6 +401,19 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 		preferences.scoringbands[BAND_SUBMM] - 48);
 	gtk_box_pack_start (GTK_BOX (rightvbox), bb29, FALSE, FALSE, 0);
 
+	frame = gtk_frame_new (_("Awards"));
+	gtk_box_pack_start (GTK_BOX (vbox), frame, FALSE, FALSE, 0);
+	vbox3 = gtk_vbox_new (FALSE, 0);
+	gtk_container_add (GTK_CONTAINER (frame), vbox3);
+	label = gtk_label_new (_("Awards to add to the scoring window"));
+	gtk_container_add (GTK_CONTAINER (vbox3), label);
+	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+	hsep = gtk_hseparator_new ();
+	gtk_container_add (GTK_CONTAINER (vbox3), hsep);
+	bwac = gtk_check_button_new_with_label ("WAC (Worked All Continents)");
+	gtk_box_pack_start (GTK_BOX (vbox3), bwac, FALSE, FALSE, 0);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (bwac), preferences.awardswac);
+
 	label = gtk_label_new (_("Worked Before"));
 	gtk_notebook_set_tab_label (GTK_NOTEBOOK (notebook),
 		gtk_notebook_get_nth_page (GTK_NOTEBOOK (notebook), 0), label);
@@ -684,6 +703,35 @@ on_menu_dialogs_activate(GtkMenuItem * menuitem, gpointer user_data)
 		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bb29));
 		scoringbands[BAND_SUBMM] = check ? '1' : '0';
 
+		check = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(bwac));
+		if (check)
+		{
+			if (preferences.awardswac == 0)
+			{
+				GtkWidget *awardsnotebook = lookup_widget (scorewindow, "awardsnotebook");
+				notebook_append_wacpage (scorewindow, awardsnotebook);
+				fill_scoring_arrays ();
+				update_wacscoring ();
+			}
+			preferences.awardswac = 1;
+		}
+		else
+		{
+			if (preferences.awardswac == 1)
+			{
+				GtkWidget *awardsnotebook = lookup_widget (scorewindow, "awardsnotebook");
+				GtkWidget *scrolledwindow2 = lookup_widget (scorewindow, "scrolledwindow2");
+				gtk_notebook_remove_page (GTK_NOTEBOOK(awardsnotebook),
+					gtk_notebook_page_num (GTK_NOTEBOOK(awardsnotebook), scrolledwindow2));
+				GtkWidget *countrytreeview = lookup_widget (scorewindow, "countrytreeview");
+				GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (countrytreeview));
+				gtk_tree_model_get_iter (model, &iter, gtk_tree_path_new_from_string ("1"));
+				for (j = 0; j < MAX_BANDS + 1; j++)
+					gtk_list_store_set (GTK_LIST_STORE (model), &iter, j, "", -1);
+			}
+			preferences.awardswac = 0;
+		}
+
 		countrytreeview = lookup_widget (scorewindow, "countrytreeview");
 		gtk_tree_view_column_set_visible (gtk_tree_view_get_column
 (GTK_TREE_VIEW(countrytreeview), BAND_2190 + 1), scoringbands[BAND_2190] - 48);
