@@ -35,7 +35,7 @@
 #include "xlog_enum.h"
 #include "main.h"
 
-extern statetype state;
+extern programstatetype programstate;
 extern GtkWidget *mainnotebook;
 extern GtkWidget *mainwindow;
 extern GList *logwindowlist;
@@ -188,7 +188,7 @@ on_menu_dupecheck_activate (GtkMenuItem * menuitem, gpointer user_data)
 		gtk_box_pack_start (GTK_BOX (dupecheckstatusbar_hbox),
 			dupecheckprogressbar, TRUE, TRUE, 0);
 
-		if (state.dupecheck == 0)
+		if (programstate.dupecheck == 0)
 			gtk_toggle_button_set_active
 				(GTK_TOGGLE_BUTTON (dupecheckthisradiobutton), TRUE);
 		else
@@ -196,9 +196,9 @@ on_menu_dupecheck_activate (GtkMenuItem * menuitem, gpointer user_data)
 				(GTK_TOGGLE_BUTTON (dupecheckallradiobutton), TRUE);
 
 		gtk_toggle_button_set_active
-			(GTK_TOGGLE_BUTTON (dupecheckbuttonmode), state.notdupecheckmode);
+			(GTK_TOGGLE_BUTTON (dupecheckbuttonmode), programstate.notdupecheckmode);
 		gtk_toggle_button_set_active
-			(GTK_TOGGLE_BUTTON (dupecheckbuttonband), state.notdupecheckband);
+			(GTK_TOGGLE_BUTTON (dupecheckbuttonband), programstate.notdupecheckband);
 		gtk_dialog_set_default_response (GTK_DIALOG (dupecheckdialog),
 						 GTK_RESPONSE_OK);
 		g_signal_connect ((gpointer) cancel_button, "clicked",
@@ -219,16 +219,16 @@ on_menu_dupecheck_activate (GtkMenuItem * menuitem, gpointer user_data)
 
 			if (gtk_toggle_button_get_active
 				(GTK_TOGGLE_BUTTON (dupecheckthisradiobutton)))
-				state.dupecheck = 0;
+				programstate.dupecheck = 0;
 			else
-				state.dupecheck = 1;
-			state.notdupecheckmode = gtk_toggle_button_get_active
+				programstate.dupecheck = 1;
+			programstate.notdupecheckmode = gtk_toggle_button_get_active
 				(GTK_TOGGLE_BUTTON(dupecheckbuttonmode));
-			state.notdupecheckband = gtk_toggle_button_get_active
+			programstate.notdupecheckband = gtk_toggle_button_get_active
 				(GTK_TOGGLE_BUTTON(dupecheckbuttonband));
 
 			/* all or this page */
-			if (state.dupecheck == 0)
+			if (programstate.dupecheck == 0)
 			{
 				page = gtk_notebook_get_current_page
 					(GTK_NOTEBOOK(mainnotebook));
@@ -259,7 +259,7 @@ on_menu_dupecheck_activate (GtkMenuItem * menuitem, gpointer user_data)
 					}
 					gtk_tree_model_get (logmodel, &iter, CALL, &callsign, -1);
 					temp = g_strdup (callsign);
-					if (!state.notdupecheckband)
+					if (!programstate.notdupecheckband)
 					{
 						gtk_tree_model_get (logmodel, &iter, BAND, &band, -1);
 						enumband = freq2enum (band);
@@ -267,7 +267,7 @@ on_menu_dupecheck_activate (GtkMenuItem * menuitem, gpointer user_data)
 						temp = g_strconcat (temp, str, NULL);
 						g_free (str);
 					}
-					if (!state.notdupecheckmode)
+					if (!programstate.notdupecheckmode)
 					{
 						gtk_tree_model_get (logmodel, &iter, MODE, &mode, -1);
 						enummode = mode2enum (mode);
@@ -410,7 +410,7 @@ on_menu_dupecheck_activate (GtkMenuItem * menuitem, gpointer user_data)
 					}
 					gtk_tree_model_get (logmodel, &iter, CALL, &callsign, -1);
 					temp = g_strdup (callsign);
-					if (!state.notdupecheckband)
+					if (!programstate.notdupecheckband)
 					{
 						gtk_tree_model_get (logmodel, &iter, BAND, &band, -1);
 						enumband = freq2enum (band);
@@ -418,7 +418,7 @@ on_menu_dupecheck_activate (GtkMenuItem * menuitem, gpointer user_data)
 						temp = g_strconcat (temp, str, NULL);
 						g_free (str);
 					}
-					if (!state.notdupecheckmode)
+					if (!programstate.notdupecheckmode)
 					{
 						gtk_tree_model_get (logmodel, &iter, MODE, &mode, -1);
 						enummode = freq2enum (mode);
