@@ -1,21 +1,24 @@
 /*
- * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- */
+
+   xlog - GTK+ logging program for amateur radio operators
+   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+
+   This file is part of xlog.
+
+   Xlog is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Xlog is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with xlog.  If not, see <http://www.gnu.org/licenses/>.
+
+*/
 
 /* gui_dxcclistdialog.c - creation of the dxcclist
  *
@@ -28,9 +31,10 @@
 #include "support.h"
 #include "dxcc.h"
 #include "main.h"
+#include "awards_enum.h"
 
 extern GPtrArray *dxcc;
-extern statetype state;
+extern programstatetype programstate;
 
 /* sort function for the latitude, longitude and timezone columns */
 static gint
@@ -136,7 +140,7 @@ on_menu_dxcclist_activate (GtkMenuItem *menuitem, gpointer user_data)
 	lat = g_strdup ("");
 	lon = g_strdup ("");
 	tz = g_strdup ("");
-	for (i = 1; i < state.countries; i++)
+	for (i = 1; i < programstate.countries; i++)
 	{
 		dxcc_data *d = g_ptr_array_index (dxcc, i);
 		lat = g_strdup_printf ("%3.2f", (double)d->latitude/100);
@@ -144,7 +148,7 @@ on_menu_dxcclist_activate (GtkMenuItem *menuitem, gpointer user_data)
 		tz = g_strdup_printf ("%2.1f", (double)d->timezone/10);
 		gtk_list_store_append (GTK_LIST_STORE (model), &iter);
 		gtk_list_store_set (GTK_LIST_STORE (model), &iter,
-			0, i, 1, d->px, 2, d->countryname, 3, d->continent, 4, d->cq,
+			0, i, 1, d->px, 2, d->countryname, 3, enum_to_cont(d->continent), 4, d->cq,
 			5, d->itu, 6, lat, 7, lon, 8, tz, -1);
 	}
 	g_free (lon);
