@@ -1,21 +1,24 @@
 /*
- * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- */
+
+   xlog - GTK+ logging program for amateur radio operators
+   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+
+   This file is part of xlog.
+
+   Xlog is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Xlog is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with xlog.  If not, see <http://www.gnu.org/licenses/>.
+
+*/
 
 #include <sys/types.h>
 #include <stdio.h>
@@ -50,6 +53,7 @@
 #include "gui_exportdialog.h"
 #include "gui_tracedialog.h"
 #include "gui_awards_dxcc.h"
+#include "gui_awards_wac.h"
 #include "support.h"
 #include "preferences.h"
 #include "gui_tracedialog.h"
@@ -169,6 +173,7 @@ static GtkActionEntry entries[] =
   { "Sort", GTK_STOCK_SORT_ASCENDING, N_("Sort by Date"), "<control><shift>O", "Sort log by date", G_CALLBACK(on_sort_log_activate) },
   { "Awards", GTK_STOCK_INDEX, N_("Awards"), "", "Overview of Awards", NULL },
   { "DXCC", GTK_STOCK_INFO, "DXCC", "<control>1", "DXCC worked/confirmed", G_CALLBACK(on_awards_dxcc_activate) },
+  { "WAC", GTK_STOCK_INFO, "WAC", "<control>2", "WAC worked/confirmed", G_CALLBACK(on_awards_wac_activate) },
 
   { "Defaults", GTK_STOCK_INDEX, N_("Defaults"), "<control>L", "Default values to use for logging", G_CALLBACK(on_menu_defaults_activate) },
   { "Dialogs", GTK_STOCK_JUSTIFY_FILL, N_("Dialogs and Windows"), "<control>B", "Settings for dialogs and windows used", G_CALLBACK(on_menu_dialogs_activate) },
@@ -182,8 +187,6 @@ static GtkActionEntry entries[] =
 
   { "Bugs", GTK_STOCK_DIALOG_INFO, N_("Bugs"), "", "How to report bugs", G_CALLBACK(on_helpbugs_activate) },
   { "Changelog", GTK_STOCK_DIALOG_INFO, N_("Changelog"), "", "Read the changelog", G_CALLBACK(on_helpchangelog_activate) },
-  { "Faq", GTK_STOCK_DIALOG_QUESTION, N_("Faq"), "", "Frequently asked questions", G_CALLBACK(on_helpfaq_activate) },
-  { "Thanks", GTK_STOCK_DIALOG_INFO, N_("Thanks"), "", "Thanks to these hams", G_CALLBACK(on_helpthanks_activate) },
   { "Todo", GTK_STOCK_DIALOG_INFO, N_("Todo"), "", "Things to do for future versions", G_CALLBACK(on_helptodo_activate) },
 
   { "1", GTK_STOCK_JUMP_TO, "Log 1", "<alt>1", "", G_CALLBACK(on_menu_log_activate) },
@@ -203,7 +206,7 @@ static GtkToggleActionEntry toggle_entries[] =
   { "Keyer", "xlog_stock_cwdaemon", N_("Keyer"), "<control>R", "Activate keyer interface", G_CALLBACK(on_keyer_activate) },
   { "Scoring", NULL, N_("Scoring Window"), "<control>J", "Show/hide the scoring window", G_CALLBACK(on_scoring_activate) },
   { "ShowToolbar", NULL, N_("Show Toolbar"), "<control>T", "Show/hide the toolbar", G_CALLBACK(on_view_toolbar_activate) },
-  { "WorkedBefore", NULL, N_("Worked Before"), "<control>4", "Show/hide the worked before dialog", G_CALLBACK(on_menu_worked_activate) },
+  { "WorkedBefore", NULL, N_("Worked Before"), "<control><shift>W", "Show/hide the worked before window", G_CALLBACK(on_menu_worked_activate) },
 };
 
 static const char *ui_description =
@@ -248,6 +251,7 @@ static const char *ui_description =
 "		<separator name='sep6'/>"
 "		<menu action='Awards'>"
 "		  <menuitem action='DXCC'/>"
+"		  <menuitem action='WAC'/>"
 "		</menu>"
 "	 </menu>"
 "	 <menu action='TabsMenu'>"
@@ -272,8 +276,6 @@ static const char *ui_description =
 "		<menu action='Documentation'>"
 "		  <menuitem action='Bugs'/>"
 "		  <menuitem action='Changelog'/>"
-"		  <menuitem action='Faq'/>"
-"		  <menuitem action='Thanks'/>"
 "		  <menuitem action='Todo'/>"
 "		</menu>"
 "	  <separator name='sep8'/>"
