@@ -1,21 +1,24 @@
 /*
- * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- */
+
+   xlog - GTK+ logging program for amateur radio operators
+   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+
+   This file is part of xlog.
+
+   Xlog is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Xlog is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with xlog.  If not, see <http://www.gnu.org/licenses/>.
+
+*/
 
 #include <gtk/gtk.h>
 #include <sys/types.h>
@@ -40,7 +43,7 @@
 GtkWidget *preferencesdialog;
 extern preferencestype preferences;
 extern GtkWidget *mainwindow;
-extern statetype state;
+extern programstatetype programstate;
 
 void
 on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
@@ -79,7 +82,6 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	GSList *modesradiobutton_group = NULL, *bandsradiobutton_group = NULL,
 		*remoteradiobutton_group = NULL, *backupradiobutton_group = NULL,
 		*saveradiobutton_group = NULL;
-	GtkTooltips *tooltips;
 
 	gchar *temp, *font;
 	gboolean toggletrue;
@@ -97,7 +99,6 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	/* creation of the dialog */
 	/**************************/
 
-	tooltips = gtk_tooltips_new ();
 	preferencesdialog = gtk_dialog_new_with_buttons (_("xlog - preferences"),
 		GTK_WINDOW(mainwindow), GTK_DIALOG_DESTROY_WITH_PARENT,
 		GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL, 
@@ -120,10 +121,10 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 		(_("Enable type and find"));
 	gtk_box_pack_start
 		(GTK_BOX (clockvbox), typeaheadfindcheckbutton, FALSE, FALSE, 0);
-	gtk_tooltips_set_tip (tooltips, typeaheadfindcheckbutton, _(
+	gtk_widget_set_tooltip_text (typeaheadfindcheckbutton, _(
 		"Search all the logs for a callsign match and when found, fill "
 		"in name, QTH, locator and remarks like in the previous QSO when "
-		"these fields are empty"), NULL);
+		"these fields are empty"));
 	distqrbcheckbutton = gtk_check_button_new_with_label
 		(_("Use free fields (when present) to add distance and azimuth to the log"));
 	gtk_label_set_line_wrap (GTK_LABEL (GTK_BIN (distqrbcheckbutton)->child), TRUE);
@@ -325,8 +326,8 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	rigsetconfentry = gtk_entry_new ();
 	gtk_box_pack_start (GTK_BOX (hamlibvbox), rigsetconfentry, FALSE, FALSE, 0);
 	gtk_entry_set_max_length (GTK_ENTRY (rigsetconfentry), 80);
-	gtk_tooltips_set_tip (tooltips, rigsetconfentry, 
-		_("example: rts_state=ON,timeout=600,serial_speed=19200"), NULL);
+	gtk_widget_set_tooltip_text (rigsetconfentry, 
+		_("example: rts_state=ON,timeout=600,serial_speed=19200"));
 	gtk_entry_set_activates_default (GTK_ENTRY (rigsetconfentry), TRUE);
 
 	hamlibseparator = gtk_hseparator_new ();
@@ -428,8 +429,8 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	pathbutton = gtk_button_new_from_stock (GTK_STOCK_OPEN);
 	gtk_widget_set_size_request (pathbutton, 100, -1);
 	gtk_box_pack_start (GTK_BOX (pathhbox), pathbutton, FALSE, FALSE, 0);
-	gtk_tooltips_set_tip
-		(tooltips, pathbutton, _("Click here to change the path"), NULL);
+	gtk_widget_set_tooltip_text
+		(pathbutton, _("Click here to change the path"));
 
 	logshseparator = gtk_hseparator_new ();
 	gtk_box_pack_start (GTK_BOX (logsvbox), logshseparator, TRUE, TRUE, 10);
@@ -512,8 +513,8 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 	backupbutton = gtk_button_new_from_stock (GTK_STOCK_OPEN);
 	gtk_widget_set_size_request (backupbutton, 100, -1);
 	gtk_box_pack_start (GTK_BOX (backuphbox), backupbutton, FALSE, FALSE, 0);
-	gtk_tooltips_set_tip
-		(tooltips, backupbutton, _("Click here to change the path"), NULL);
+	gtk_widget_set_tooltip_text
+		(backupbutton, _("Click here to change the path"));
 
 	fontframe = gtk_frame_new (_("Font"));
 	gtk_box_pack_start (GTK_BOX (vboxpage5), fontframe, FALSE, FALSE, 0); 	 
@@ -882,7 +883,7 @@ on_menu_preferences_activate (GtkMenuItem * menuitem, gpointer user_data)
 		preferences.units = gtk_combo_box_get_active 
 			(GTK_COMBO_BOX (unitscombo))  == 1 ? 0 : 1;
 
-		state.mylocation = setlocation (preferences.latitude, preferences.NS,
+		programstate.mylocation = setlocation (preferences.latitude, preferences.NS,
 			preferences.longitude, preferences.EW);
 
 		/* get the comma seperated list of modes and assign 
