@@ -1,21 +1,24 @@
 /*
- * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- */
+
+   xlog - GTK+ logging program for amateur radio operators
+   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+
+   This file is part of xlog.
+
+   Xlog is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Xlog is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with xlog.  If not, see <http://www.gnu.org/licenses/>.
+
+*/
 
 /*
  * cabrillo.c - scanner for Cabrillo format - 2.0
@@ -43,18 +46,20 @@
 #include "logfile.h"
 #include "preferences.h"
 #include "utils.h"
+#include "main.h"
 
 extern preferencestype preferences;
+extern programstatetype programstate;
 
 /*
  * fields to be stored in the cabrillo file
  */
 static const gint cabrillo_fields[] =
-	{ BAND, MODE, DATE, GMT, RST, CALL, MYRST };
+	{ BAND, MODE, DATE, GMT, RST, CALL, MYRST, REMARKS };
 
 static const gint cabrillo_widths[] = { 5, 2, 10, 4, 10, 13, 10 };
 static const gint cabrillo_ss_widths[] = { 5, 2, 10, 4, 13, 10, 13 };
-static const gint cabrillo_na_widths[] = { 5, 2, 10, 4, 21, 10, 21 };
+static const gint cabrillo_na_widths[] = { 5, 2, 10, 4, 20, 10, 21 };
 static const gint cabrillo_field_nr = 7;
 
 static gint cabrillo_open (LOGDB *);
@@ -82,7 +87,7 @@ gint
 cabrillo_open (LOGDB * handle)
 {
 	FILE *fp;
-	const gint xlog_fields [] = {DATE, GMT, CALL, BAND, MODE, RST, MYRST};
+	const gint xlog_fields [] = {DATE, GMT, CALL, BAND, MODE, RST, MYRST, REMARKS};
 
 	fp = fopen (handle->path, "r");
 	if (!fp)
@@ -90,7 +95,7 @@ cabrillo_open (LOGDB * handle)
 	handle->priv = (gpointer) fp;
 
  	/* set columns to be used in xlog */
-	handle->column_nr = 7;
+	handle->column_nr = 8;
 	memcpy (handle->column_fields, xlog_fields, sizeof (xlog_fields));
 	/* TODO: set and use handle->column_widths */
 
@@ -157,7 +162,7 @@ cabrillo_qso_append (LOGDB * handle, const qso_t * q)
 	 * there's no exchange fields in xlog. However, the exchange information
 	 * may be piggybacked by the rst field. eg. "599ON".
 	 */
-	if (!strcmp (q_mode, "SSB") || !strcmp (q_mode, "LSB")
+	if (!strcmp (q_mode, "SSB") || !strcmp (q_mode, "USB")
 			|| !strcmp (q_mode, "LSB") || !strcmp (q_mode, "FM"))
 		rst_len = 2;
 	else
@@ -351,6 +356,12 @@ cabrillo_qso_foreach (LOGDB * handle,
 				}
 				q[cabrillo_fields[i]] =
 					g_strdup_printf ("%s%s", field, buf);
+				/* add the remark field if present */
+				if ((i == 6) && (strlen(programstate.importremark) > 0))
+				{
+					q[cabrillo_fields[i + 1]] =
+						g_strdup (programstate.importremark);
+				}
 			}
 
 			else
