@@ -1,21 +1,24 @@
 /*
- * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- */
+
+   xlog - GTK+ logging program for amateur radio operators
+   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+
+   This file is part of xlog.
+
+   Xlog is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Xlog is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with xlog.  If not, see <http://www.gnu.org/licenses/>.
+
+*/
 
 /*
  * edi.c - scanner for EDI (Electronic Data Interchange) IARU Region 1
@@ -111,6 +114,7 @@ edi_create (LOGDB * handle)
 		"RAdr2=\n"
 		"RPoCo=\n"
 		"RCity=\n"
+		"RCoun=\n"
 		"RHBBS=\n"
 		"PBand=\n"
 		"PSect=\n"
@@ -147,7 +151,7 @@ edi_qso_append (LOGDB * handle, const qso_t * q)
 	gchar rst[16], exch[16] = "", my_rst[16], my_exch[16] = "";
 	gchar *date, *p;
 	gint rst_len;
-	gint mode, kms, result, l;
+	gint mode, kms, result = -1, l;
 
 	/*
 	 * there's no exchange fields in xlog. However, the exchange information
@@ -172,7 +176,7 @@ edi_qso_append (LOGDB * handle, const qso_t * q)
 	else
 		date = g_strdup ("");
 
-	if (!strcmp(q[MODE], "SSB")) {
+	if (!q[MODE] || !strcmp(q[MODE], "SSB")) {
 		mode = 1;
 	} else if (!strcmp(q[MODE], "CW")) {
 		mode = 2;
@@ -194,6 +198,7 @@ edi_qso_append (LOGDB * handle, const qso_t * q)
 		result = wwl (preferences.locator, q[LOCATOR], &kms, &l);
 	else 
 		kms = 0;
+	if (result == -1) kms = 0;
 
 	/* 
 	 * CSV-alike format 
@@ -204,7 +209,7 @@ edi_qso_append (LOGDB * handle, const qso_t * q)
 //020907;1404;PI4GN;1;59;001;59;005;;JO33II;515;;;;
 	if (q[LOCATOR])
 		fprintf (fp, "%s;%s;%s;%d;%s;%s;%s;%s;;%s;%d;;;;\n",
-		date, q[GMT], q[CALL], mode, rst, exch, my_rst, my_exch, q[LOCATOR],kms);
+		date, q[GMT], q[CALL], mode, rst, exch, my_rst, my_exch, q[LOCATOR], kms);
 	else
 		fprintf (fp, "%s;%s;%s;%d;%s;%s;%s;%s;;;%d;;;;\n",
 		date, q[GMT], q[CALL], mode, rst, exch, my_rst, my_exch, kms);
