@@ -1,21 +1,24 @@
 /*
- * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- */
+
+   xlog - GTK+ logging program for amateur radio operators
+   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+
+   This file is part of xlog.
+
+   Xlog is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Xlog is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with xlog.  If not, see <http://www.gnu.org/licenses/>.
+
+*/
 
 /*
  * preferences.c - load and save program settings in xml format
@@ -123,6 +126,7 @@ static gint make_default_preferences (void)
 	preferences.scoreheight = 300;
 	preferences.scoringbands = g_strdup ("01101111111000000000000000000");
 	preferences.distqrb = 0;
+	preferences.awardswac = 0;
 	return 0;
 }
 
@@ -638,6 +642,12 @@ parseloadpreferences (xmlDocPtr p, xmlNodePtr cur)
 			preferences.distqrb = atoi ((const char *)key);
 			free (key);
 		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"awardswac")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.awardswac = atoi ((const char *)key);
+			free (key);
+		}
 
 	cur = cur->next;
 	}
@@ -1155,6 +1165,12 @@ void parsesavepreferences (xmlNodePtr cur)
 			xmlNodeSetContent (node, (const xmlChar *)key);
 			g_free (key);
 		}
+		else if (!g_ascii_strcasecmp ((gchar *)node->name, "awardswac"))
+		{
+			key = g_strdup_printf ("%d", preferences.awardswac);
+			xmlNodeSetContent (node, (const xmlChar *)key);
+			g_free (key);
+		}
 	}
 }
 
@@ -1251,6 +1267,7 @@ newsavepreferences (xmlNodePtr cur)
 	xmlNewTextChild (cur, NULL, (const xmlChar *)"scoreheight", (const xmlChar *)"300");
 	xmlNewTextChild (cur, NULL, (const xmlChar *)"scoringbands", (const xmlChar *)"01101111111000000000000000000");
 	xmlNewTextChild (cur, NULL, (const xmlChar *)"distqrb", (const xmlChar *)"0");
+	xmlNewTextChild (cur, NULL, (const xmlChar *)"awardswac", (const xmlChar *)"0");
 	g_free (homedir);
 }
 
