@@ -1,21 +1,24 @@
 /*
- * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- */
+
+   xlog - GTK+ logging program for amateur radio operators
+   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+
+   This file is part of xlog.
+
+   Xlog is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Xlog is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with xlog.  If not, see <http://www.gnu.org/licenses/>.
+
+*/
 
 /*
  * remote.c - remote data support
@@ -78,7 +81,7 @@
 msgtype msgbuf;
 remotetype remote;
 gint server_sockfd;
-extern statetype state;
+extern programstatetype programstate;
 extern preferencestype preferences;
 extern glong msgid;
 extern GtkWidget *mainwindow;
@@ -210,7 +213,7 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 					if (g_ascii_strcasecmp (argument, "HAMLIB") == 0)
 					{
 						get_mode ();
-						qso[MODE] = rigmode (state.rigmode);
+						qso[MODE] = rigmode (programstate.rigmode);
 					}
 					else
 					{
@@ -227,7 +230,7 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 					if (g_ascii_strcasecmp (argument, "HAMLIB") == 0)
 					{
 						get_smeter ();
-						qso[RST] = g_strdup (state.rigrst);
+						qso[RST] = g_strdup (programstate.rigrst);
 					}
 					else
 						qso[RST] = g_strndup (argument, 15);
@@ -309,7 +312,7 @@ addtolog_or_qsoframe (gint type, gchar * entry)
 					{
 						get_powerlevel ();
 						if (GTK_WIDGET_VISIBLE (powerhbox))
-							qso[POWER] = g_strdup_printf ("%d", state.rigpower * 256 / 100000);
+							qso[POWER] = g_strdup_printf ("%d", programstate.rigpower / 1000);
 					}
 					else
 					{
@@ -556,7 +559,7 @@ static gboolean
 tcp_client_activity (GIOChannel *source, GIOCondition cond, gpointer data)
 {
 	gchar buf[1024];
-	guint num_read = 0;
+	gsize num_read = 0;
 	GIOStatus res;
 
 	if (cond == G_IO_IN)
