@@ -1,21 +1,24 @@
 /*
- * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- */
+
+   xlog - GTK+ logging program for amateur radio operators
+   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+
+   This file is part of xlog.
+
+   Xlog is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Xlog is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with xlog.  If not, see <http://www.gnu.org/licenses/>.
+
+*/
 
 /*
  * utils.c - assorted utilities
@@ -52,11 +55,12 @@
 #include "callbacks_mainwindow_qsoframe.h"
 #include "main.h"
 #include "hamlib-utils.h"
+#include "awards_enum.h"
 
 gint statusbartimer;
 extern GtkWidget *mainwindow, *keyerwindow, *b4window, *scorewindow;
 extern preferencestype preferences;
-extern statetype state;
+extern programstatetype programstate;
 extern remotetype remote;
 extern gchar **qso;
 extern gchar *xlogdir;
@@ -188,7 +192,7 @@ statusbar_timeout (gpointer data)
 	gtk_statusbar_pop (GTK_STATUSBAR (statusbar), 1);
 	gtk_statusbar_push (GTK_STATUSBAR (statusbar), 1, _("Ready."));
 	g_source_remove (statusbartimer);
-	state.statustimer = FALSE;
+	programstate.statustimer = FALSE;
 	return FALSE;
 }
 
@@ -201,19 +205,19 @@ update_statusbar (gchar * string)
 	statusbar = lookup_widget (mainwindow, "statusbar");
 	gtk_statusbar_pop (GTK_STATUSBAR (statusbar), 1);
 	gtk_statusbar_push (GTK_STATUSBAR (statusbar), 1, string);
-	if (state.statustimer)
+	if (programstate.statustimer)
 		g_source_remove (statusbartimer);
 	statusbartimer = g_timeout_add (30000, statusbar_timeout, NULL);
-	state.statustimer = TRUE;
+	programstate.statustimer = TRUE;
 }
 
 /* free mem in state struct */
 static void
 freestate (void)
 {
-	g_free (state.mylocation);
-	g_free (state.rigrst);
-	g_free (state.searchstr);
+	g_free (programstate.mylocation);
+	g_free (programstate.rigrst);
+	g_free (programstate.searchstr);
 }
 
 /* free mem in prefs struct */
@@ -273,6 +277,7 @@ save_windowsize_and_cleanup (void)
 
 	/* free the tables array */
 	cleanup_dxcc ();
+	cleanup_area ();
 
 	/* free the qso array */
 	for (i = 0; i < QSO_FIELDS; i++)
@@ -357,10 +362,10 @@ save_windowsize_and_cleanup (void)
 
 	/* detach shared mem and destroy it */
 #if HAVE_SYS_SHM_H
-	if (state.shmid != -1)
+	if (programstate.shmid != -1)
 		{
 			shmdt (shareCall);
-			shmctl (state.shmid, IPC_RMID, NULL);
+			shmctl (programstate.shmid, IPC_RMID, NULL);
 		}
 #endif
 
@@ -680,28 +685,41 @@ my_strreplace(const char *str, const char *delimiter, const char *replacement)
 	return ret;
 }
 
-/* check if the awards entry contains a valid DXCC string */
+/* check if the awards entry contains a valid awards string */
 gchar *
-valid_awards_entry (gchar *a)
+valid_awards_entry (gchar *a, guint *st, guint *zone, guint *cont)
 {
 	gchar **s = g_strsplit (a, ",", -1);
-	gchar **dxcc = NULL, *dup = NULL;
+	gchar *p = NULL, *dup = NULL;
 	guint i = 0;
 
+	*st = 99;
+	*zone = 99;
+	*cont = 99;
 	for (;;)
 	{
 		if (s[i] == NULL) break;
-		dxcc = g_strsplit (s[i], "-", -1);
-		if (strcmp (dxcc[0], "DXCC-") && dxcc[1] && strlen (dxcc[1]) > 0)
-			{
-				g_strfreev (s);
-				dup = g_strdup (dxcc[1]);
-				g_strfreev (dxcc);
-				return (dup);
-			}
+		p = index (s[i], '-');
+		if (p)
+		{
+			if (!g_ascii_strncasecmp(s[i], "DXCC", 4))
+				dup = g_strdup (p + 1);
+			else if (!g_ascii_strncasecmp(s[i], "WAZ", 3))
+				*zone = atoi (p + 1);
+			else if (!g_ascii_strncasecmp(s[i], "WAC", 3))
+				*cont = cont_to_enum (p + 1);
+			else if (!g_ascii_strncasecmp(s[i], "WAS", 4))
+				*st = state_to_enum (p + 1);
+		}
 		i++;
 	}
-	if (dxcc) g_strfreev (dxcc);
 	g_strfreev (s);
 	return dup;
 }
+
+gboolean
+qslreceived(gchar *in)
+{
+	if (in && (!g_ascii_strcasecmp (in, "x") || !g_ascii_strcasecmp (in, "y"))) return TRUE;
+	return FALSE;
+}
