@@ -1,21 +1,24 @@
 /*
- * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
- * GNU Library General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
- */
+
+   xlog - GTK+ logging program for amateur radio operators
+   Copyright (C) 2001 - 2007 Joop Stakenborg <pg4i@amsat.org>
+
+   This file is part of xlog.
+
+   Xlog is free software: you can redistribute it and/or modify
+   it under the terms of the GNU General Public License as published by
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+
+   Xlog is distributed in the hope that it will be useful,
+   but WITHOUT ANY WARRANTY; without even the implied warranty of
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+   GNU General Public License for more details.
+
+   You should have received a copy of the GNU General Public License
+   along with xlog.  If not, see <http://www.gnu.org/licenses/>.
+
+*/
 
 /*
  * wwl.c - see description below by IK0ZSN, adopted for xlog April 2002
@@ -53,7 +56,7 @@ wwl (gchar * my, gchar * dx, gint *p, gint *l)
 			msg = g_strdup_printf (_("%s: not a valid locator"), my);
 			update_statusbar (msg);
 			g_free (msg);
-			return 0;
+			return 1;
 		}
 
 	strlen_dx = strlen (dx);
@@ -62,7 +65,7 @@ wwl (gchar * my, gchar * dx, gint *p, gint *l)
 			msg = g_strdup_printf (_("%s: not a valid locator"), dx);
 			update_statusbar (msg);
 			g_free (msg);
-			return 0;
+			return 1;
 		}
 
 	strcpy (my_wwl, my);
@@ -86,7 +89,7 @@ wwl (gchar * my, gchar * dx, gint *p, gint *l)
 			msg = g_strdup_printf (_("%s: not a valid locator"), my_wwl);
 			update_statusbar (msg);
 			g_free (msg);
-			return 0;
+			return 1;
 		}
 
 	t = z * 20 - 180 + n * 2 + x / 12 + 1.0 / 24;
@@ -112,7 +115,7 @@ wwl (gchar * my, gchar * dx, gint *p, gint *l)
 			msg = g_strdup_printf (_("%s: not a valid locator"), dx_wwl);
 			update_statusbar (msg);
 			g_free (msg);
-			return 0;
+			return 1;
 		}
 
 	v = z * 20 - 180 + n * 2 + x / 12 + 1.0 / 24;
@@ -143,7 +146,7 @@ wwl (gchar * my, gchar * dx, gint *p, gint *l)
 	*p = (gint) (atan (sqrt (d) / c) * 6371.33) + .5;
 	if (*p < 0) *p = 20002 + *p;
 	if (*p < 1) *p = 0;
-	return 1;
+	return 0;
 }
 
 void
@@ -163,7 +166,7 @@ updatelocatorframe (gchar * locator)
 	if (strlen (locator) >= 2)
 	{
 		result = wwl (preferences.locator, locator, &p, &l);
-		if (result != 0)
+		if (result == 0)
 		{
 			if (preferences.units == 1)
 				locatorlabeltext = g_strdup_printf
